@@ -17,7 +17,7 @@ except PackageNotFoundError:
 
 import di.api as api  # noqa: E402
 from di.container import BaseContainer, Container  # noqa: E402
-from di.dependant import Dependant, JoinedDependant  # noqa: E402
+from di.dependant import Dependant, JoinedDependant, Marker  # noqa: E402
 from di.executors import (  # noqa: E402
     AsyncExecutor,
     ConcurrentAsyncExecutor,
@@ -33,4 +33,5 @@ __all__ = (
     "ConcurrentAsyncExecutor",
     "AsyncExecutor",
     "SyncExecutor",
+    "Marker",
 )
