@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import Any, Dict, Iterable, Mapping, Sequence
 
-from di.api.dependencies import DependantBase, DependencyParameter
+from di.api.dependencies import DependantBase
 from di.api.scopes import Scope
 from di.exceptions import ScopeViolationError, UnknownScopeError
 
@@ -21,15 +21,12 @@ def check_is_inner(
 
 def check_scope(dep: DependantBase[Any], scope_idxs: Dict[Scope, int]) -> None:
     if dep.scope not in scope_idxs:
-        raise UnknownScopeError(
-            f"Dependency{dep} has an unknown scope {dep.scope}."
-            f" Did you forget to enter the {dep.scope} scope?"
-        )
+        raise UnknownScopeError(f"Dependency{dep} has an unknown scope {dep.scope}.")
 
 
 def validate_scopes(
     scopes: Sequence[Scope],
-    dag: Mapping[DependantBase[Any], Iterable[DependencyParameter]],
+    dag: Mapping[DependantBase[Any], Iterable[DependantBase[Any]]],
 ) -> None:
     """Validate that dependencies all have a valid scope and
     that dependencies only depend on outer scopes or their own scope.
@@ -39,5 +36,5 @@ def validate_scopes(
     for dep, predecessors in dag.items():
         check_scope(dep, scope_idxs)
         for predecessor in predecessors:
-            check_scope(predecessor.dependency, scope_idxs)
-            check_is_inner(dep, predecessor.dependency, scope_idxs)
+            check_scope(predecessor, scope_idxs)
+            check_is_inner(dep, predecessor, scope_idxs)
