@@ -1,16 +1,35 @@
 from __future__ import annotations
 
 import inspect
+import sys
 from typing import Any, Generic, List, NamedTuple, Optional, TypeVar
 
+if sys.version_info < (3, 8):
+    from typing_extensions import Protocol, runtime_checkable
+else:
+    from typing import Protocol, runtime_checkable
+
 from di._utils.types import CacheKey
 from di.api.providers import DependencyProviderType
 from di.api.scopes import Scope
 
 T = TypeVar("T")
+T_co = TypeVar("T_co", covariant=True)
 
 
-__all__ = ("CacheKey", "DependantBase", "DependencyParameter")
+__all__ = (
+    "CacheKey",
+    "DependantBase",
+    "DependencyParameter",
+    "InjectableClassProvider",
+)
+
+
+@runtime_checkable
+class InjectableClassProvider(Protocol[T_co]):
+    @classmethod
+    def __di_dependency__(cls, param: inspect.Parameter) -> DependantBase[Any]:
+        ...
 
 
 class DependantBase(Generic[T]):
@@ -32,17 +51,6 @@ class DependantBase(Generic[T]):
         """Collect all of the sub dependencies for this dependant"""
         raise NotImplementedError
 
-    def register_parameter(self, param: inspect.Parameter) -> DependantBase[Any]:
-        """Called by the parent so that us / this / the child can register
-        the parameter it is attached to.
-
-        This is used to register self.call,
-        but can also be used for recording type annotations or parameter names.
-
-        This method may return the same instance or another DependantBase altogether.
-        """
-        raise NotImplementedError
-
 
 class DependencyParameter(NamedTuple):
     dependency: DependantBase[Any]
