@@ -1,6 +1,6 @@
 import inspect
 import sys
-from typing import Any, Generator, cast
+from typing import Generator, Type, TypeVar
 
 if sys.version_info < (3, 9):
     from typing_extensions import Annotated, get_args, get_origin
@@ -8,14 +8,16 @@ else:
     from typing import Annotated, get_args, get_origin
 
 from di._utils.inspect import get_parameters
-from di.api.dependencies import DependantBase
 
 __all__ = ("get_parameters", "get_markers_from_parameter")
 
 
+T = TypeVar("T")
+
+
 def get_markers_from_parameter(
-    param: inspect.Parameter,
-) -> Generator[DependantBase[Any], None, None]:
+    param: inspect.Parameter, marker_cls: Type[T]
+) -> Generator[T, None, None]:
     """Infer a sub-dependant from a parameter of this Dependant's .call
 
 
@@ -30,5 +32,5 @@ def get_markers_from_parameter(
         # This is a somewhat arbitrary choice, but it is the convention we'll go with
         # See https://www.python.org/dev/peps/pep-0593/#id18 for more details
         for arg in reversed(get_args(param.annotation)):
-            if isinstance(arg, DependantBase):
-                yield cast(DependantBase[Any], arg)
+            if isinstance(arg, marker_cls):
+                yield arg
